@@ -19,12 +19,12 @@
 
 using namespace Diff2;
 
-bool diffModelCompare(DiffModel* model1, DiffModel* model2)
+static bool diffModelCompare(DiffModel* model1, DiffModel* model2)
 {
-	return *model1 < *model2;
+    return *model1 < *model2;
 }
 
 void DiffModelList::sort()
 {
-	qSort(begin(), end(), diffModelCompare);
+    std::sort(begin(), end(), diffModelCompare);
 }
